@@ -6,25 +6,25 @@ from hatchling.utils.constants import DEFAULT_CONFIG_FILE
 
 
 def test_incompatible_environment(hatch, temp_dir, helpers, build_env_config):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
         assert result.exit_code == 0, result.output
 
-    path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
     project = Project(path)
     config = dict(project.raw_config)
-    config['build-system']['requires'].append('foo')
-    config['project']['dynamic'].append('dependencies')
+    config["build-system"]["requires"].append("foo")
+    config["project"]["dynamic"].append("dependencies")
     project.save_config(config)
-    helpers.update_project_environment(project, 'hatch-build', {'python': '9000', **build_env_config})
+    helpers.update_project_environment(project, "hatch-build", {"python": "9000", **build_env_config})
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('dep', 'show', 'requirements')
+        result = hatch("dep", "show", "requirements")
 
     assert result.exit_code == 1, result.output
     assert result.output == helpers.dedent(
@@ -35,25 +35,25 @@ def test_incompatible_environment(hatch, temp_dir, helpers, build_env_config):
 
 
 def test_project_only(hatch, helpers, temp_dir, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir / 'my-app'
+    project_path = temp_dir / "my-app"
 
     project = Project(project_path)
     config = dict(project.raw_config)
-    config['project']['dependencies'] = ['foo-bar-baz']
+    config["project"]["dependencies"] = ["foo-bar-baz"]
     project.save_config(config)
 
     with project_path.as_cwd():
-        result = hatch('dep', 'show', 'requirements', '-p')
+        result = hatch("dep", "show", "requirements", "-p")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -64,23 +64,23 @@ def test_project_only(hatch, helpers, temp_dir, config_file):
 
 
 def test_environment_only(hatch, helpers, temp_dir, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir / 'my-app'
+    project_path = temp_dir / "my-app"
 
     project = Project(project_path)
-    helpers.update_project_environment(project, 'default', {'dependencies': ['foo-bar-baz']})
+    helpers.update_project_environment(project, "default", {"dependencies": ["foo-bar-baz"]})
 
     with project_path.as_cwd():
-        result = hatch('dep', 'show', 'requirements', '-e')
+        result = hatch("dep", "show", "requirements", "-e")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -91,31 +91,31 @@ def test_environment_only(hatch, helpers, temp_dir, config_file):
 
 
 def test_default_both(hatch, helpers, temp_dir, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir / 'my-app'
+    project_path = temp_dir / "my-app"
 
     project = Project(project_path)
     config = dict(project.raw_config)
-    config['project']['dependencies'] = ['foo-bar-baz']
-    config['project']['optional-dependencies'] = {
-        'feature1': ['bar-baz-foo'],
-        'feature2': ['bar-foo-baz'],
-        'feature3': ['foo-baz-bar'],
+    config["project"]["dependencies"] = ["foo-bar-baz"]
+    config["project"]["optional-dependencies"] = {
+        "feature1": ["bar-baz-foo"],
+        "feature2": ["bar-foo-baz"],
+        "feature3": ["foo-baz-bar"],
     }
     project.save_config(config)
-    helpers.update_project_environment(project, 'default', {'dependencies': ['baz-bar-foo']})
+    helpers.update_project_environment(project, "default", {"dependencies": ["baz-bar-foo"]})
 
     with project_path.as_cwd():
-        result = hatch('dep', 'show', 'requirements')
+        result = hatch("dep", "show", "requirements")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -127,20 +127,20 @@ def test_default_both(hatch, helpers, temp_dir, config_file):
 
 
 def test_unknown_feature(hatch, helpers, temp_dir, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir / 'my-app'
+    project_path = temp_dir / "my-app"
 
     with project_path.as_cwd():
-        result = hatch('dep', 'show', 'requirements', '-f', 'foo')
+        result = hatch("dep", "show", "requirements", "-f", "foo")
 
     assert result.exit_code == 1, result.output
     assert result.output == helpers.dedent(
@@ -151,32 +151,32 @@ def test_unknown_feature(hatch, helpers, temp_dir, config_file):
 
 
 def test_features_only(hatch, helpers, temp_dir, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir / 'my-app'
+    project_path = temp_dir / "my-app"
 
     project = Project(project_path)
     config = dict(project.raw_config)
-    config['project']['dependencies'] = ['foo-bar-baz']
-    config['project']['optional-dependencies'] = {
-        'feature1': ['bar-baz-foo'],
-        'feature2': ['bar-foo-baz'],
-        'feature3': ['foo-baz-bar'],
-        'feature4': ['baz-foo-bar'],
+    config["project"]["dependencies"] = ["foo-bar-baz"]
+    config["project"]["optional-dependencies"] = {
+        "feature1": ["bar-baz-foo"],
+        "feature2": ["bar-foo-baz"],
+        "feature3": ["foo-baz-bar"],
+        "feature4": ["baz-foo-bar"],
     }
     project.save_config(config)
-    helpers.update_project_environment(project, 'default', {'dependencies': ['baz-bar-foo']})
+    helpers.update_project_environment(project, "default", {"dependencies": ["baz-bar-foo"]})
 
     with project_path.as_cwd():
-        result = hatch('dep', 'show', 'requirements', '-f', 'feature2', '-f', 'feature1')
+        result = hatch("dep", "show", "requirements", "-f", "feature2", "-f", "feature1")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -188,32 +188,32 @@ def test_features_only(hatch, helpers, temp_dir, config_file):
 
 
 def test_include_features(hatch, helpers, temp_dir, config_file):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir / 'my-app'
+    project_path = temp_dir / "my-app"
 
     project = Project(project_path)
     config = dict(project.raw_config)
-    config['project']['dependencies'] = ['foo-bar-baz']
-    config['project']['optional-dependencies'] = {
-        'feature1': ['bar-baz-foo'],
-        'feature2': ['bar-foo-baz'],
-        'feature3': ['foo-baz-bar'],
-        'feature4': ['baz-foo-bar'],
+    config["project"]["dependencies"] = ["foo-bar-baz"]
+    config["project"]["optional-dependencies"] = {
+        "feature1": ["bar-baz-foo"],
+        "feature2": ["bar-foo-baz"],
+        "feature3": ["foo-baz-bar"],
+        "feature4": ["baz-foo-bar"],
     }
     project.save_config(config)
-    helpers.update_project_environment(project, 'default', {'dependencies': ['baz-bar-foo']})
+    helpers.update_project_environment(project, "default", {"dependencies": ["baz-bar-foo"]})
 
     with project_path.as_cwd():
-        result = hatch('dep', 'show', 'requirements', '--all')
+        result = hatch("dep", "show", "requirements", "--all")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -229,17 +229,17 @@ def test_include_features(hatch, helpers, temp_dir, config_file):
 
 
 def test_plugin_dependencies_unmet(hatch, helpers, temp_dir, config_file, mock_plugin_installation):
-    config_file.model.template.plugins['default']['tests'] = False
+    config_file.model.template.plugins["default"]["tests"] = False
     config_file.save()
 
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
 
     assert result.exit_code == 0, result.output
 
-    project_path = temp_dir / 'my-app'
+    project_path = temp_dir / "my-app"
 
     dependency = os.urandom(16).hex()
     (project_path / DEFAULT_CONFIG_FILE).write_text(
@@ -253,11 +253,11 @@ def test_plugin_dependencies_unmet(hatch, helpers, temp_dir, config_file, mock_p
 
     project = Project(project_path)
     config = dict(project.raw_config)
-    config['project']['dependencies'] = ['foo-bar-baz']
+    config["project"]["dependencies"] = ["foo-bar-baz"]
     project.save_config(config)
 
     with project_path.as_cwd():
-        result = hatch('dep', 'show', 'requirements', '-p')
+        result = hatch("dep", "show", "requirements", "-p")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
