@@ -10,7 +10,7 @@ from hatchling.utils.constants import DEFAULT_CONFIG_FILE
 class TestNoProject:
     def test_random_directory(self, hatch, temp_dir, helpers):
         with temp_dir.as_cwd():
-            result = hatch('version')
+            result = hatch("version")
 
         assert result.exit_code == 1, result.output
         assert result.output == helpers.dedent(
@@ -20,14 +20,14 @@ class TestNoProject:
         )
 
     def test_configured_project(self, hatch, temp_dir, helpers, config_file):
-        project = 'foo'
-        config_file.model.mode = 'project'
+        project = "foo"
+        config_file.model.mode = "project"
         config_file.model.project = project
         config_file.model.projects = {project: str(temp_dir)}
         config_file.save()
 
         with temp_dir.as_cwd():
-            result = hatch('version')
+            result = hatch("version")
 
         assert result.exit_code == 1, result.output
         assert result.output == helpers.dedent(
@@ -38,27 +38,27 @@ class TestNoProject:
 
 
 def test_other_backend_show(hatch, temp_dir, helpers):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
         assert result.exit_code == 0, result.output
 
-    path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
-    (path / 'src' / 'my_app' / '__init__.py').write_text('__version__ = "9000.42"')
+    (path / "src" / "my_app" / "__init__.py").write_text('__version__ = "9000.42"')
 
     project = Project(path)
     config = dict(project.raw_config)
-    config['build-system']['requires'] = ['flit-core']
-    config['build-system']['build-backend'] = 'flit_core.buildapi'
-    del config['project']['license']
+    config["build-system"]["requires"] = ["flit-core"]
+    config["build-system"]["build-backend"] = "flit_core.buildapi"
+    del config["project"]["license"]
     project.save_config(config)
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version')
+        result = hatch("version")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -73,25 +73,25 @@ def test_other_backend_show(hatch, temp_dir, helpers):
 
 
 def test_other_backend_set(hatch, temp_dir, helpers):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
         assert result.exit_code == 0, result.output
 
-    path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
     project = Project(path)
     config = dict(project.raw_config)
-    config['build-system']['requires'] = ['flit-core']
-    config['build-system']['build-backend'] = 'flit_core.buildapi'
-    del config['project']['license']
+    config["build-system"]["requires"] = ["flit-core"]
+    config["build-system"]["build-backend"] = "flit_core.buildapi"
+    del config["project"]["license"]
     project.save_config(config)
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version', '1.0.0')
+        result = hatch("version", "1.0.0")
 
     assert result.exit_code == 1, result.output
     assert result.output == helpers.dedent(
@@ -102,24 +102,24 @@ def test_other_backend_set(hatch, temp_dir, helpers):
 
 
 def test_incompatible_environment(hatch, temp_dir, helpers, build_env_config):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        result = hatch('new', project_name)
+        result = hatch("new", project_name)
         assert result.exit_code == 0, result.output
 
-    path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
     project = Project(path)
     config = dict(project.raw_config)
-    config['build-system']['requires'].append('foo')
+    config["build-system"]["requires"].append("foo")
     project.save_config(config)
-    helpers.update_project_environment(project, 'hatch-build', {'python': '9000', **build_env_config})
+    helpers.update_project_environment(project, "hatch-build", {"python": "9000", **build_env_config})
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version')
+        result = hatch("version")
 
     assert result.exit_code == 1, result.output
     assert result.output == helpers.dedent(
@@ -129,19 +129,19 @@ def test_incompatible_environment(hatch, temp_dir, helpers, build_env_config):
     )
 
 
-@pytest.mark.usefixtures('mock_backend_process')
+@pytest.mark.usefixtures("mock_backend_process")
 def test_show_dynamic(hatch, helpers, temp_dir):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        hatch('new', project_name)
+        hatch("new", project_name)
 
-    path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version')
+        result = hatch("version")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -155,15 +155,15 @@ def test_show_dynamic(hatch, helpers, temp_dir):
     )
 
 
-@pytest.mark.usefixtures('mock_backend_process')
+@pytest.mark.usefixtures("mock_backend_process")
 def test_plugin_dependencies_unmet(hatch, helpers, temp_dir, mock_plugin_installation):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        hatch('new', project_name)
+        hatch("new", project_name)
 
-    path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
     dependency = os.urandom(16).hex()
@@ -177,7 +177,7 @@ def test_plugin_dependencies_unmet(hatch, helpers, temp_dir, mock_plugin_install
     )
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version')
+        result = hatch("version")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -194,24 +194,24 @@ def test_plugin_dependencies_unmet(hatch, helpers, temp_dir, mock_plugin_install
 
 
 @pytest.mark.requires_internet
-@pytest.mark.usefixtures('mock_backend_process')
+@pytest.mark.usefixtures("mock_backend_process")
 def test_no_compatibility_check_if_exists(hatch, helpers, temp_dir, mocker):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        hatch('new', project_name)
+        hatch("new", project_name)
 
-    project_path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    project_path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
     project = Project(project_path)
     config = dict(project.raw_config)
-    config['build-system']['requires'].append('binary')
+    config["build-system"]["requires"].append("binary")
     project.save_config(config)
 
     with project_path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version')
+        result = hatch("version")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -224,9 +224,9 @@ def test_no_compatibility_check_if_exists(hatch, helpers, temp_dir, mocker):
         """
     )
 
-    mocker.patch('hatch.env.virtual.VirtualEnvironment.check_compatibility', side_effect=Exception('incompatible'))
+    mocker.patch("hatch.env.virtual.VirtualEnvironment.check_compatibility", side_effect=Exception("incompatible"))
     with project_path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version')
+        result = hatch("version")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -237,19 +237,19 @@ def test_no_compatibility_check_if_exists(hatch, helpers, temp_dir, mocker):
     )
 
 
-@pytest.mark.usefixtures('mock_backend_process')
+@pytest.mark.usefixtures("mock_backend_process")
 def test_set_dynamic(hatch, helpers, temp_dir):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        hatch('new', project_name)
+        hatch("new", project_name)
 
-    path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version', 'minor,rc')
+        result = hatch("version", "minor,rc")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -264,7 +264,7 @@ def test_set_dynamic(hatch, helpers, temp_dir):
     )
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version')
+        result = hatch("version")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -275,29 +275,29 @@ def test_set_dynamic(hatch, helpers, temp_dir):
     )
 
 
-@pytest.mark.usefixtures('mock_backend_process')
+@pytest.mark.usefixtures("mock_backend_process")
 def test_set_dynamic_downgrade(hatch, helpers, temp_dir):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        hatch('new', project_name)
+        hatch("new", project_name)
 
-    path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
-    (path / 'src' / 'my_app' / '__about__.py').write_text('__version__ = "21.1.2"')
+    (path / "src" / "my_app" / "__about__.py").write_text('__version__ = "21.1.2"')
 
     # This one fails, because it's a downgrade without --force
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version', '21.1.0', catch_exceptions=True)
+        result = hatch("version", "21.1.0", catch_exceptions=True)
 
     assert result.exit_code == 1, result.output
-    assert str(result.exception) == 'Version `21.1.0` is not higher than the original version `21.1.2`'
+    assert str(result.exception) == "Version `21.1.0` is not higher than the original version `21.1.2`"
 
     # Try again, this time with --force
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version', '--force', '21.1.0')
+        result = hatch("version", "--force", "21.1.0")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -309,7 +309,7 @@ def test_set_dynamic_downgrade(hatch, helpers, temp_dir):
     )
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version')
+        result = hatch("version")
 
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
@@ -321,45 +321,45 @@ def test_set_dynamic_downgrade(hatch, helpers, temp_dir):
 
 
 def test_show_static(hatch, temp_dir):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        hatch('new', project_name)
+        hatch("new", project_name)
 
-    path = temp_dir / 'my-app'
+    path = temp_dir / "my-app"
 
     project = Project(path)
     config = dict(project.raw_config)
-    config['project']['version'] = '1.2.3'
-    config['project']['dynamic'].remove('version')
-    config['tool']['hatch']['metadata'] = {'hooks': {'foo': {}}}
+    config["project"]["version"] = "1.2.3"
+    config["project"]["dynamic"].remove("version")
+    config["tool"]["hatch"]["metadata"] = {"hooks": {"foo": {}}}
     project.save_config(config)
 
     with path.as_cwd():
-        result = hatch('version')
+        result = hatch("version")
 
     assert result.exit_code == 0, result.output
-    assert result.output == '1.2.3\n'
+    assert result.output == "1.2.3\n"
 
 
 def test_set_static(hatch, helpers, temp_dir):
-    project_name = 'My.App'
+    project_name = "My.App"
 
     with temp_dir.as_cwd():
-        hatch('new', project_name)
+        hatch("new", project_name)
 
-    path = temp_dir / 'my-app'
-    data_path = temp_dir / 'data'
+    path = temp_dir / "my-app"
+    data_path = temp_dir / "data"
     data_path.mkdir()
 
     project = Project(path)
     config = dict(project.raw_config)
-    config['project']['version'] = '1.2.3'
-    config['project']['dynamic'].remove('version')
+    config["project"]["version"] = "1.2.3"
+    config["project"]["dynamic"].remove("version")
     project.save_config(config)
 
     with path.as_cwd(env_vars={ConfigEnvVars.DATA: str(data_path)}):
-        result = hatch('version', 'minor,rc')
+        result = hatch("version", "minor,rc")
 
     assert result.exit_code == 1, result.output
     assert result.output == helpers.dedent(
