@@ -7,24 +7,19 @@ from ..new.feature_no_src_layout import get_files as get_template_files
 
 
 def get_files(**kwargs):
-    relative_root = kwargs.get('relative_root', '')
+    relative_root = kwargs.get("relative_root", "")
 
-    files = []
-    for f in get_template_files(**kwargs):
-        files.append(File(Path(relative_root, f.path), f.contents))
-
-    files.append(File(Path(relative_root, kwargs['package_name'], 'lib.so'), ''))
-    files.append(
+    files = [File(Path(relative_root, f.path), f.contents) for f in get_template_files(**kwargs)]
+    files.extend((
+        File(Path(relative_root, kwargs["package_name"], "lib.so"), ""),
         File(
-            Path(relative_root, '.gitignore'),
+            Path(relative_root, ".gitignore"),
             """\
 *.pyc
 *.so
 *.h
 """,
-        )
-    )
-    files.append(
+        ),
         File(
             Path(relative_root, DEFAULT_BUILD_SCRIPT),
             """\
@@ -37,18 +32,16 @@ class CustomHook(BuildHookInterface):
         pathlib.Path('my_app', 'lib.so').touch()
         pathlib.Path('my_app', 'lib.h').touch()
 """,
-        )
-    )
-    files.append(
+        ),
         File(
-            Path(relative_root, 'PKG-INFO'),
+            Path(relative_root, "PKG-INFO"),
             f"""\
 Metadata-Version: {DEFAULT_METADATA_VERSION}
-Name: {kwargs['project_name']}
+Name: {kwargs["project_name"]}
 Version: 0.0.1
 License-File: LICENSE.txt
 """,
-        )
-    )
+        ),
+    ))
 
     return files
